<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    // KEEP these in alphabetical order.
    // KEEP them indented correctly.
    // KEEP all the language files up-to-date with each other.
    // DON'T MAKE A MESS!
    return array(
        '(Unknown)'
            => '(Sconosciuto)',
        '(Unnamed)'
            => '(Senza Nome)',
        '2D Donut Chart'
            => 'Grafico ad anello 2D',
        '2D Horizontal Bar Graph'
            => 'Grafico a barre horizontale 2D',
        '2D Pie Chart'
            => 'Grafico a torta 2D',
        '2D Vertical Bar Graph'
            => 'Grafico a barre verticale 2D',
        '3D Pie Chart'
            => 'Grafico a torta 3D',
        '3D Vertical Bar Graph'
            => 'Grafico a barre verticale 3D',
        '<strong>Zurmo</strong> is a <strong>Customer Relationship Management</strong> system by <strong>Zurmo Inc.</strong>'
            => '<strong>Zurmo</strong> è un sistema di <strong>Customer Relationship Management</strong> creato da <strong>Zurmo Inc.</strong>',
        '<strong>Zurmo</strong> is licensed under the GPLv3.  You can read the license <a href="http://www.zurmo.org/license">here</a>.'
            => '<strong>Zurmo</strong> è rilasciato sotto la licenza GPL3.  Potete leggere la licenza <a href="http://www.zurmo.org/license">qui</a>.',
        '<strong>Zurmo</strong> uses the following great Open Source tools and frameworks:'
            => '<strong>Zurmo</strong> utilizza i seguenti strumenti e framework di Open Source:',
        'A large amount of data has been requested for export.  You will receive a notification with the download link when the export is complete.'
            => 'C\'è una grande quantità di dati ad esportare',
        'About Zurmo'
            => 'Tutto su Zurmo',
        'Access Administration Tab'
            => 'Accesso Amministrazione',
        'Access Currency Configuration'
            => 'Accesso Valute',
        'Access Developer Tools'
            => 'Accesso a strumenti di sviluppo',
        'Access Failure'
            => 'Fallimento nell\'accesso',
        'Access Global Configuration'
            => 'Accesso a la Configurazione Globale',
        'Access Groups Tab'
            => 'Accesso Gruppi',
        'Access Roles Tab'
            => 'Accesso Ruoli',
        'Active'
            => 'Attivo',
        'Active currencies can be used when creating new records and as a default currency for a user.'
            => 'Le valute attive sono usando quando create nuovi records e come una valute di default per un utente.',
        'Active languages can be used by users. The system language and any language in use by a user cannot be inactivated'
            => 'Le lingue attive sono disponibile ai utenti.  La lingua del sistema e qualunque lingua usata per un utente non si può essere inattiva.',
        'Ad-hoc / Owner'
            => 'Ad-hoc / Proprietario',
        'Add Comment'
            => 'Aggiungi commento',
        'Add criteria'
            => 'Aggiungi criteri',
        'Add Currency'
            => 'Nuova Valuta',
        'Add new fields, remove ones you don\'t need and change the layout using Designer.'
            => 'Utilisate Desginer per creare un nuevo campo, rimuovere campi non utilizzati, e modificare il layout.',
        'Address'
            => 'Indirizzo',
        'Admin'
            => 'Admin', // Same Word Translated
        'Alert'
            => 'Allarme',
        'Allow'
            => 'Permettere',
        'Amount'
            => 'Valuta',
        'An error has occurred. Please click'
            => 'C\'era un errore.  Prego di cliccare',
        'An error occured during login. Please try again.'
            => 'Errore login. Prego di provare di nuovo.',
        'Any City'
            => 'Città',
        'Any Country'
            => 'Paese',
        'Any Email Address'
            => 'Indirizzo email',
        'Any Invalid Email'
            => 'Email non valido',
        'Any Opted Out Email'
            => 'Email opt-out',
        'Any Postal Code'
            => 'CAP',
        'Any State'
            => 'Provincia',
        'Any Street'
            => 'Via',
        'Application is in maintenance mode, and only Super Administrators can access it.'
            => 'L\'applicazione è in modalità di manutenzione, e solo Super Administrator può accedervi.',
        'Application is in maintenance mode. Please try again later.'
            => 'L\'applicazione è in modalità di manutenzione. Si prega di riprovare più tardi.',
        'Application Name'
            => 'Nome dell\'applicazione',
        'are required.'
            => 'sono richiesti.',
        'Are you number one{spaceAndFirstName}? Find out how you size up to your colleagues on the Leaderboard.'
            => 'Pronti? Attenti! Via! Vedete il Leaderboard per vedere como paragonate con i vostri colleghi.',
        'Are you sure you want to delete this group?'
            => 'Siete sicuro di voler eliminare questo gruppo?',
        'Are you sure you want to delete this role?'
            => 'Siete sicuro di voler eliminare questo ruolo?',
        'Attachment'
            => 'Allegato',
        'Attachments'
            => 'Allegati',
        'Audit Event'
            => 'Lista dei cambiamenti',
        'Audit Trail'
            => 'Log di modifica',
        'Automotive'
            => 'Automobilistico',
        'Banking'
            => 'Bancaria',
        'Business Services'
            => 'Servizi di business',
        'by {ownerStringContent}'
            => 'di {ownerStringContent}',
        'Cache has been successfully cleaned.'
            => 'Cache cancella con successo.',
        'Changes to active currencies saved successfully.'
            => 'Valute attive modificati con successo.',
        'Changes to active languages saved successfully.'
            => 'Lingue attive modificati con successo.',
        'Chart Type'
            => 'Tipo di grafico',
        'City'
            => 'Città',
        'Clear Cache'
            => 'Cancella cache',
        'Click on the Map link on records to see the customer location on Google Maps.'
            => 'Clicca sul link mappa per visualizzare la posizione geograficha con Google Maps.',
        'Close'
            => 'Chiudi',
        'Code'
            => 'Codice',
        'Comment'
            => 'Commenta',
        'Configuration'
            => 'Configurazine',
        'Configure'
            => 'Configura',
        'Convert'
            => 'Converti',
        'Copyright &#169; Zurmo Inc., 2012. All Rights reserved.'
            => 'Copyright &#169; Zurmo Inc., 2012. Tutti i diritti riservati.',
        'Could not remove relation.'
            => 'Impossibile rimuovere la relazione.',
        'Could not save relation.'
            => 'Impossibile salvare la relazione.',
        'Could not use this API call for HAS_ONE relationships.'
            => 'Impossibile utilizzare questa chiamata API per i relazioni HAS_ONE.',
        'Country'
            => 'Paese',
        'Create Group'
            => 'Nuovo Gruppo',
        'Create Groups'
            => 'Crea Gruppi',
        'Create Role'
            => 'Nuovo Ruolo',
        'Create Roles'
            => 'Crea Ruoli',
        'Created'
            => 'Creato',
        'created by {ownerStringContent}'
            => 'crea per {ownerStringContent}',
        'Criteria Selected <span class="icon-clear">Z</span>'
            => 'Criteri Selezionati <span class="icon-clear">Z</span>',
        'Currencies: Create'
            => 'Valute: Crea',
        'Currencies: List'
            => 'Valute: Lista',
        'Currency'
            => 'Valuta',
        'Currency Configuration'
            => 'Configurazione di valuta',
        'Currency in use.'
            => 'Valuta in uso.',
        'Currency Rates Update Job'
            => 'Job corso delle valute',
        'Currency Value'
            => 'Valore',
        'Custom data updated successfully.'
            => 'Dati personalizzati aggiornati correttamente.',
        'Customer'
            => 'Cliente',
        'Dashboard portlet list page size'
            => 'Numero degli elementi nella lista portlet',
        'Data'
            => 'Dati',
        'Database upgrade not completed. Please try again later.'
            => 'Aggiornamento del database non completata. Si prega di riprovare più tardi.',
        'days'
            => 'giorni',
        'Dead'
            => 'Perso',
        'Decide who can view and edit a record, set Group rights and permissions.'
            => 'Decide chi può vedere e modificare i record con Diritti dei Gruppi e Privilegi.',
        'Delete Group'
            => 'Elimina il Gruppo',
        'Delete Groups'
            => 'Elimina Gruppi',
        'Delete Role'
            => 'Elimina il Ruolo',
        'Delete Roles'
            => 'Elimina Ruoli',
        'Deny'
            => 'Rifiutare',
        'Department'
            => 'Dipartimento',
        'Description'
            => 'Descrizione',
        'Developer Tools'
            => 'Strumenti per Sviluppatori',
        'Dr.'
            => 'Dr.', // Same Word Translated
        'Due On'
            => 'Data scadenza',
        'Edit charts on the dashboard by clicking the config icon in the top right of each portlet.'
            => 'Clicca sull\'icona di configurazione in alto a destra dei portlets per modificare i grafici nel Dashboard.',
        'Email'
            => 'Email', // Same Word Translated
        'Email Address'
            => 'Indirizzo Email',
        'Enable game notification popup'
            => 'Attiva la notifica popup per ludicizzazione',
        'Energy'
            => 'Energia',
        'Event Name'
            => 'Nome evento',
        'every'
            => 'cada',
        'Everyone'
            => 'Todos',
        'Fields with'
            => 'Campi con',
        'File Content'
            => 'Contenuto di file',
        'File failed to upload. The file is empty.'
            => 'errore durante il caricamento di file.  Il file è vuoto.',
        'Files'
            => 'File',
        'Filter By Created User'
            => 'Filtra creato dall\'utente',
        'Filtered Lists'
            => 'Liste filtrate',
        'Financial Services'
            => 'Servizi finanziari',
        'Find what you need quickly using the global search at the top of the screen.'
            => 'Trova quello che ti serve velocemente utilizzando la ricerca globale nella parte superiore dello schermo.',
        'First Name'
            => 'Nome',
        'Forums'
            => 'Forum',
        'Global and Basic Search Fields'
            => 'Campi di ricerca globale e semplice',
        'Global Configuration'
            => 'Configurazione globale',
        'Global configuration saved successfully.'
            => 'Configurazione globale modificata con successo.',
        'Global search'
            => 'Ricerca globale',
        'Go to Search'
            => 'alla Ricerca',
        'Got questions{spaceAndFirstName}? Find answers in the Zurmo Wiki.'
            => 'Avete domande{spaceAndFirstName}? Trova le risposte nel Wiki Zurmo.',
        'Group'
            => 'Gruppo',
        'Group Module Permissions'
            => 'Privilegi dei Gruppi',
        'Group Policies'
            => 'Regole dei Gruppi',
        'Group Rights'
            => 'Diritti dei Gruppi',
        'Groups'
            => 'Gruppi',
        'Groups Home'
            => 'Gruppi Home',
        'here'
            => 'qui',
        'Home'
            => 'Home', // Same Word Translated
        'If there is new metadata to load using CustomManagement, use this option.'
            => 'Se ci sono nuovi metadati da caricare per CustomManagement, clicca per eseguire.',
        'In Progress'
            => 'In corso',
        'In the case where you have reloaded the database, some cached items might still exist. This is a way to clear that cache.'
            => 'Se avete ricaricate il database, clicca per eseguire.',
        'Inbound Call'
            => 'Chiamata inbound',
        'Incorrect username or password.'
            => 'Nome utente o password non valida.',
        'Industry'
            => 'Industria',
        'Inherited - All'
            => 'Ereditare - Tutti',
        'Inherited - Allow'
            => 'Ereditare - Permettere',
        'Inherited - Deny'
            => 'Ereditare - Rifutare',
        'Inherited - No'
            => 'Ereditare - No',
        'Inherited - Owner Only'
            => 'Ereditare - Solo proprietario',
        'Inherited - Yes'
            => 'Ereditare - Si',
        'Inherited Value:'
            => 'Valore ereditato:',
        'Insurance'
            => 'Assicurazione',
        'Invalid currency code'
            => 'Codice non valido.',
        'Invalid username or password.'
            => 'Nome utente sconosciuto o password non valida.',
        'Is Invalid'
            => 'È invalido',
        'Job Title'
            => 'Titolo',
        'Label must be all lowercase.'
            => 'Tutte le lettere della etichetta devono essere minuscole.',
        'Label must not be empty.'
            => 'Etichetta non può essere vuota.',
        'Label must not contain any special characters.'
            => 'Etichetta non può avere caratteri speciali.',
        'Language'
            => 'Lingua',
        'Languages'
            => 'Lingue',
        'Languages: List'
            => 'Lingue: Lista',
        'Last Name'
            => 'Cognome',
        'Last Updated'
            => 'Ultima modifica',
        'Latitude'
            => 'Latitudine',
        'Let Zurmo crunch the numbers, add calculated fields to your records in Designer.'
            => 'Permetate a Zurmo di fare il lavoro più pesante, aggiungiate campi calcolati in Designer.',
        'List Filters'
            => 'Filtre de lista',
        'List page size'
            => 'Numero di dati per pagina',
        'List View'
            => 'Vista Elenco',
        'Load'
            => 'Carica',
        'Load a saved search'
            => 'Caricare una ricerca salvata',
        'Longitude'
            => 'Longitudine',
        'Manage Active Languages'
            => 'Gestione delle Lingue',
        'Manage Currency Configuration'
            => 'Gestione Valute e Cambi',
        'Manage Global Configuration'
            => 'Gestione Configurazione Globale',
        'Manage Groups'
            => 'Gestione dei Gruppi',
        'Manage Roles'
            => 'Gestione di Ruoli',
        'Manufacturing'
            => 'Fabbricazione',
        'map'
            => 'carta',
        'Member'
            => 'Membro',
        'Member Of'
            => 'Membro di',
        'Members'
            => 'Membri',
        'Menu'
            => 'Menù',
        'Missing Record'
            => 'Record mancante',
        'Missing Required Fields'
            => 'Campi obbligatori mancanti',
        'Mobile Phone'
            => 'Cellulare',
        'Model was not created.'
            => 'Il modello non era creato.',
        'Model was not updated.'
            => 'Il modello non era aggiornato.',
        'Model was updated, but there were issues with relations.'
            => 'Il modello è stato aggiornato, ma ci sono stati problemi con le relazioni.',
        'Modify Structure'
            => 'Modifica la struttura',
        'Module Name - Plural'
            => 'Nome di modulo - plurale',
        'Module Name - Plural (lowercase)'
            => 'Nome di module - plurale (minuscolo)',
        'Module Name - Singular'
            => 'Nome di module - singolare',
        'Module Name - Singular (lowercase)'
            => 'Nome di module - singolare (minuscolo)',
        'Module Permissions'
            => 'Privilegi del Modulo',
        'Module Permissions Saved Successfully.'
            => 'Privilegi del Modulo modificati con successo.',
        'Mr.'
            => 'Sig.',
        'Mrs.'
            => 'Sig.ra',
        'Ms.'
            => 'Sig.na',
        'My List Configuration View'
            => 'Il mio elenco di configurazioni della vista',
        'Need help{spaceAndFirstName}, why not ask a question in the forum?'
            => '{spaceAndFirstName}, bisogno di aiuto? Fare una domanda nel forum.',
        'Need to see the big picture? Click Roll-Up to see activities from related records.'
            => 'Clicca roll-up per vedere le attività di record correlati.',
        'Need to update multiple records at once? Select them from the list and hit the Update button.'
            => 'Per aggiornare molti dati in stesso tempo, spuntate i dati nella Vista Elenco e clicca il bottone "Aggiornamento globale".',
        'Never'
            => 'Mai',
        'New'
            => 'Nuovo',
        'No Results Found'
            => 'Non resultati',
        'Non Members'
            => 'Non membri',
        'Not Set'
            => 'Default',
        'Not Set - Ad-hoc / Owner'
            => 'Default - Ad-hoc / Proprietario',
        'Notifications'
            => 'Notificazione',
        'Office Fax'
            => 'Fax',
        'Office Phone'
            => 'Telefono Ufficio',
        'Oh no!'
            => 'Oh!',
        'Once a day, early in the morning.'
            => 'Una volta per giorno, presto alla mattina',
        'Once a week, early in the morning.'
            => 'Una volta per settimana, presto alla mattina',
        'Only Items I Own'
            => 'Solo i miei elementi',
        'Opt Out'
            => 'Opt out',
        'owned by {ownerStringContent}'
            => 'proprio di {ownerStringContent}',
        'Owner'
            => 'Proprietario',
        'Owner and users in'
            => 'Proprietario e utenti en',
        'Owner Only'
            => 'Solamente il proprietario',
        'Parent Group'
            => 'Gruppo Padre',
        'Parent Role'
            => 'Ruolo Padre',
        'Parlez vous Français{spaceAndFirstName}? Choose your preferred language in your My Profile area.'
            => 'Selezionate vostra lingua preferita in Il mio profile.',
        'Password'
            => 'Password', // Same Word Translated
        'Permissions'
            => 'Privilegi',
        'Permitable'
            => 'Permetto',
        'Please provide data.'
            => 'Prego di provare i dati.',
        'Please resolve the following issues for {modelString}:'
            => 'Si prega di risolvere i seguenti problemi per {modelString}:',
        'Please use FireFox, Chrome, or Internet Explorer.'
            => 'Prego di usare FireFox, Chrome, o Internet Explorer.',
        'Policies'
            => 'Regole',
        'Policies Saved Successfully.'
            => 'Regole modificate con successo.',
        'Popup list page size'
            => 'Numero degli elementi nella lista popup',
        'Post to Profile'
            => 'Pubblica',
        'Postal Code'
            => 'CAP',
        'Primary Address'
            => 'Indirizzo primario',
        'Primary Email'
            => 'Email Primario',
        'Qualified'
            => 'Qualificato',
        'Rate to'
            => 'Tasso a',
        'Rate To Base'
            => 'Tasso al',
        'Read'
            => 'Leggere',
        'Read permissions rebuild complete.'
            => 'Ricostruzione dei privilegi di leggere è completa.',
        'Recently Viewed'
            => 'Ultime visti',
        'Recently Viewed lets you jump back to any records you have looked at lately.'
            => 'Ultime Visti permette di accedere rapidamente a gli elementi piu recenti.',
        'Recycled'
            => 'Riciclato',
        'Remember me next time'
            => 'Ricordami',
        'Remember{spaceAndFirstName}, the Audit Trail shows you what has changed on a record and who changed it.'
            => 'Ricorda {spaceAndFirstName}, il Log di modifica mostra la storia delle modifiche di un record et il nome dell\'utente che lo ha cambiato.',
        'Retail'
            => 'Commercio Retail',
        'Return to Admin Menu'
            => 'Ritorno al Menù Admin',
        'Rights'
            => 'Diritti',
        'Rights and Permissions'
            => 'Diritti e Privilegi',
        'Rights Saved Successfully.'
            => 'Diritti modificati con successo.',
        'Role'
            => 'Ruolo',
        'Roles'
            => 'Ruoli',
        'Roles Home'
            => 'Ruoli Home',
        'Run'
            => 'Esegui',
        'Salutation'
            => 'Saluto',
        'Save Changes'
            => 'Salva',
        'Save search'
            => 'Salva la ricerca',
        'Save yourself time and click the pencil icon to jump right in and edit your record.'
            => 'Clicca sull\'icona della matita per velocemente modificare un record.',
        'Search'
            => 'Ricerca',
        'Search by name, phone, or e-mail'
            => 'Ricerca per nome, telefono, o indirizzo e-mail.',
        'Secondary Address'
            => 'Altro indirizzo',
        'Secondary Email'
            => 'Altro Email',
        'Securable Item'
            => 'Elemento securable',
        'Security Overview'
            => 'Sicurezza',
        'See more search results by clicking the down arrow at the bottom of the screen.'
            => 'Clicca la freccia verso il basso per visualizzare più risultati di una ricerca.',
        'Select a field'
            => 'Selezionare un campo',
        'Select a Group'
            => 'Selezionare un gruppo',
        'Select a Parent Group'
            => 'Selezionate un gruppo padre',
        'Select a Parent Role'
            => 'Selezionate un ruolo padre',
        'Select a Role'
            => 'Selezionate un ruolo',
        'Self-Generated'
            => 'Autogenerato',
        'Send a test email to'
            => 'Inviare una prova di email a ',
        'Set your preferences, password, and contact details in your My Profile area.'
            => 'Potrete cambiare le vostre preferenze, password, e coordinate nella sezione Il mio profile.',
        'Settings'
            => 'Parametri',
        'Shipping Address'
            => 'Indirizzo di consegna',
        'Sign in'
            => 'Accedi',
        'Sign in required.'
            => 'Login obbligatorio.',
        'Sign out'
            => 'Esci',
        'Sign out failed.'
            => 'Logout fallito.',
        'Size'
            => 'Dimensione',
        'skipped because you do not have sufficient permissions.'
            => 'saltato perché non avete privilegi sufficienti.',
        'Sorry! Your browser is not supported.'
            => 'Spiacente! Il tuo browser non supporta.',
        'Source'
            => 'Fonte',
        'Specified custom field name was invalid.'
            => 'Nome del campo personalizzato non è valido.',
        'Stage'
            => 'Fase di Vendita',
        'Standard Fields'
            => 'Campi di default',
        'State'
            => 'Provincia',
        'Status'
            => 'Stato',
        'Street 1'
            => 'Via 1',
        'Street 2'
            => 'Via 2',
        'Sublist page size'
            => 'Numero degli elementi nella lista Sublist',
        'Successfully updated'
            => 'modificato con successo',
        'Summary'
            => 'Sommario',
        'Super Administrators'
            => 'Amministratore Super',
        'Tag Cloud fields allow you to tag records with values so that you can easily find them later.'
            => 'I campi nuvole di tags permette di associare parole chiave ai records per poter ritrovarle più tardi.',
        'Technology'
            => 'Tecnologia',
        'The currency rate web service says this currency code is invalid even though zurmo says it is valid. The rate could not be automatically updated.'
            => 'Il servizio di corsi delle valute indica che questo codice non è valido, anche se zurmo indica che è valido. Il tasso non fu aggiornato.',
        'The currency rate web service was unavailable. The rate could not be automatically updated.'
            => 'Il servizio di corsi delle valute non è disponibile. Il tasso non fu aggiornato.',
        'The currency was not removed because it is in use.'
            => 'La valuta non fu eliminata perché é in uso.',
        'The default value is {policyDefault}'
            => 'Il valore default è {policyDefault}',
        'The ID specified was invalid.'
            => 'ID non è valido.',
        'The Import Wizard helps get your data into the system easily, find it under the config icon (that\'s the cog in the top right).'
            => 'Il Guidato Importazione aiuta a importare facilmente dati nel sistema. Trova le sull\'icona di configurazione in alto a destra  dello schermo.',
        'The Notifications speech bubble keeps you up to date on important events.'
            => 'La bolla di notifica vi tiene aggiornati sugli eventi importanti.',
        'The record you are trying to access does not exist.'
            => 'Questo record è stato cancellato.',
        'The related model ID specified was invalid.'
            => 'L\'ID del modello associato non è valido.',
        'The status specified is invalid.'
            => 'Il stato specificate non é valido.',
        'There are no recently viewed items.'
            => 'Non ci sono elementi di ultime visite.',
        'There are required fields missing from the following layout: {view}.  Please contact your administrator.'
            => 'Ci sono campi obbligatori mancante del layout: {view}.  Prego di contattare il amministratore.',
        'There is no data to export.'
            => 'Non ci sono dati da esportare.',
        'This action is only available in debug mode.'
            => 'Questa azione é solamente disponibile nel modo di debug.',
        'This is <strong>version {zurmoVersion}</strong> of <strong>Zurmo</strong>.'
            => 'Voi utilizzate la <strong>versione {zurmoVersion}</strong> di <strong>Zurmo</strong>.',
        'This name is reserved. Please pick a different name.'
            => 'Questo nome e riservato.  Prego di scegliere un altro nome.',
        'Time zone'
            => 'Fuso orario',
        'Title'
            => 'Titolo',
        'to continue to the home page. If the error persists please contact your administrator.'
            => 'per continuare alla pagina Home.  Se si continua a ricevere questo messaggio, prego di contattare il amministratore.',
        'Tradeshow'
            => 'Fiera',
        'Type a currency code or name to search.'
            => 'Inserisci il codice o il nome.',
        'Unsupported action.'
            => 'Azione non supportato.',
        'Update'
            => 'Aggiorna',
        'Update Custom Data'
            => 'Aggiornamento dei dati personalizzati',
        'Updated'
            => 'Aggiornato',
        'Upload attachments to a record by clicking "More Options" when adding a note.'
            => 'Per aggiungere un allegato a un record, clicca "Altre opzioni" quando crea una Nota.',
        'User Membership'
            => 'Membri',
        'User Membership Saved Successfully.'
            => 'Membri modificati con successo.',
        'Username'
            => 'Nome utente',
        'Users'
            => 'Users',
        'Value'
            => 'Valore',
        'Values'
            => 'Valori',
        'Visit <strong>Zurmo Inc.</strong> at {url}.'
            => 'Visita <strong>Zurmo Inc.</strong> a {url}.',
        'Visit the <strong>Zurmo Open Source Project</strong> at {url}.'
            => 'Visita il <strong>Zurmo Open Source Project</strong> a {url}.',
        'Want to export your data directly to Excel? Search for the data you need and hit the Export button.'
            => 'Desideri esportare dati verso Excel? Cercare i dati che colete e clicca sul pulsante "Esporta".',
        'Website'
            => 'Sito web',
        'Welcome'
            => 'Benvenuto',
        'What is this?'
            => 'Che cos\'è?',
        'Who can read and write'
            => 'Autorizzazione di leggere/scrivere',
        'Who can read and write - Default'
            => 'Autorizzazione di leggere/scrivere',
        'Word of Mouth'
            => 'Passaparola',
        'Write'
            => 'Scrivere',
        'You can add relations only for HAS_MANY and MANY_MANY relations.'
            => 'È possibile aggiungere i rapporti solo per le relazioni HAS_MANY e MANY_MANY.',
        'You have tried to access a page you do not have access to.'
            => 'Non si è autorizzati a visualizzare questa pagina.',
        'You must have at least one active currency.'
            => 'Ha bisogno di almeno una valuta attiva.',
        'Your RedBean version is currentVersion and it should be acceptableVersion.'
            => 'Suo versione di RedBean è currentVersion e dovrebbe essere acceptableVersion.',
        'Your Yii version is currentVersion and it should be acceptableVersion.'
            => 'Suo versione di Yii è currentVersion e dovrebbe essere acceptableVersion.',
        'ZurmoCRM'
            => 'ZurmoCRM', // Same Word Translated
        '{modelString} is already connected to this record.'
            => '{modelString} è già associato a questo record.',
        '{url} (installed with Yii)'
            => '{url} (installato con Yii)',
        '{url} (version {version} is installed)'
            => '{url} (la versione {version} è installato)',
    );
?>
